BinaryFormatter

Struct BinaryFormatter 

pub struct BinaryFormatter { /* private fields */ }
This implementation of BufferFormatter trait formats provided bytes buffer in binary number system.

Implementations

Source

impl BinaryFormatter

pub fn new(provided_separator: Option<&str>) -> Self

Construct a new instance of BinaryFormatter using provided borrowed separator. In case if provided separator will be None, then default separator (:) will be used.

pub fn new_static(provided_separator: Option<&'static str>) -> Self

Construct a new instance of BinaryFormatter using provided static borrowed separator. In case if provided separator will be None, then default separator (:) will be used. This method avoids allocation for static string separators.

pub fn new_owned(provided_separator: Option<String>) -> Self

Construct a new instance of BinaryFormatter using provided owned separator. In case if provided separator will be None, then default separator (:) will be used.

pub fn new_default() -> Self

Construct a new instance of BinaryFormatter using default separator (:).